@@ -45,12 +45,14 @@ public:
         InstalledSize,
         RequiredRuntime
     };
+    Q_ENUM(PropertyKind)
 
     enum PropertyState {
         NotKnownYet = 0,
         AlreadyKnown,
         UnknownOrFailed,
     };
+    Q_ENUM(PropertyState)
 
     enum ResourceType {
         DesktopApp = 0,
@@ -58,6 +60,7 @@ public:
         Extension,
         Source
     };
+    Q_ENUM(ResourceType)
 
     struct Id {
         FlatpakInstallation * const installation;
@@ -108,7 +111,7 @@ public:
     QUrl donationURL() override;
     QString flatpakFileType() const;
     QString flatpakName() const;
-    QString license() override;
+    QJsonArray licenses() override;
     QString longDescription() override;
     QString name() const override;
     QString origin() const override;
@@ -156,7 +159,7 @@ public:
     QString installPath() const;
 
 Q_SIGNALS:
-    void propertyStateChanged(PropertyKind kind, PropertyState state);
+    void propertyStateChanged(FlatpakResource::PropertyKind kind, FlatpakResource::PropertyState state);
 
 private:
     void setArch(const QString &arch);
