@@ -26,8 +26,9 @@
 #include <QTimer>
 #include <QPointer>
 
+#include <KNotification>
+
 class QNetworkConfigurationManager;
-class KStatusNotifierItem;
 class KNotification;
 
 class DiscoverNotifier : public QObject
@@ -61,7 +62,6 @@ public:
     bool needsReboot() const { return m_needsReboot; }
 
 public Q_SLOTS:
-    void configurationChanged();
     void recheckSystemUpdateNeeded();
     void showDiscover();
     void showDiscoverUpdates();
@@ -79,12 +79,11 @@ private:
     void updateStatusNotifier();
 
     QList<BackendNotifierModule*> m_backends;
-    bool m_verbose = false;
     QTimer m_timer;
     bool m_hasSecurityUpdates = false;
     bool m_hasUpdates = false;
     bool m_needsReboot = false;
-    QNetworkConfigurationManager* const m_manager;
+    QNetworkConfigurationManager* m_manager = nullptr;
     QPointer<KNotification> m_updatesAvailableNotification;
 };
 
